nx.ui.Application - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.ui.Application Class

Extends nx.ui.AbstractComponent
Module: nx.ui

- Index
- Methods
- Properties

## Item Index

### Methods

- attach
- clearBinding
- destroy
- detach
- dispose
- getBinding
- getContainer
- notify
- onAttach
- onChildAttach
- onChildDetach
- onDetach
- register
- resolve
- setBinding
- start
- stop
- unregister
- unwatch

### Properties

- count
- model
- owner
- parent

## Methods

### `attach`

(

- `parent`
- `index`

)

Inherited from nx.ui.AbstractComponent:

Attach the component to parent.

#### Parameters:

- `parent` Object
- `index` Object

### `clearBinding`

(

- `prop`

)

Inherited from nx.Observable:

Clear binding for specified property.

#### Parameters:

- `prop` Object

### `destroy`

()

Inherited from nx.ui.AbstractComponent:

Destroy the component.

### `detach`

()

Inherited from nx.ui.AbstractComponent:

Detach the component from parent.

### `dispose`

()

Inherited from nx.Observable

Dispose the component.

### `getBinding`

(

- `prop`

)

Inherited from nx.Observable:

Get existing binding object for specified property.

#### Parameters:

- `prop` Object

#### Returns:

:

### `getContainer`

(

- `comp`

)
nx.dom.Element

Inherited from nx.ui.AbstractComponent:

Get the container for component.

#### Parameters:

- `comp` Object

#### Returns:

nx.dom.Element:

### `notify`

(

- `names`
- `oldValue`

)

Inherited from nx.Observable:

#### Parameters:

- `names` Object
- `oldValue` Object

### ``

(

- `names`
- `handler`
- `context`

)

Inherited from nx.Observable:

#### Parameters:

- `names` Object
- `handler` Object
- `context` Object

### `onAttach`

()

Inherited from nx.ui.AbstractComponent:

Template method for component attach.

### `onChildAttach`

()

Inherited from nx.ui.AbstractComponent:

Template method for child component attach.

### `onChildDetach`

()

Inherited from nx.ui.AbstractComponent:

Template method for child component detach.

### `onDetach`

()

Inherited from nx.ui.AbstractComponent:

Template method for component detach.

### `register`

(

- `name`
- `value`
- `force`

)

Inherited from nx.ui.AbstractComponent:

Register a resource.

#### Parameters:

- `name` Object
- `value` Object
- `force` Object

### `resolve`

(

- `name`

)
Any

Inherited from nx.ui.AbstractComponent:

Resolve a resource.

#### Parameters:

- `name` Object

#### Returns:

Any:

### `setBinding`

(

- `prop`
- `expr`
- `source`

)

Inherited from nx.Observable:

Set binding for specified property.

#### Parameters:

- `prop` Object
- `expr` Object
- `source` Object

### `start`

()

Start the application.

### `stop`

()

Stop the application.

### `unregister`

(

- `name`

)

Inherited from nx.ui.AbstractComponent:

Unregister a resource.

#### Parameters:

- `name` Object

### `unwatch`

(

- `names`
- `handler`
- `context`

)

Inherited from nx.Observable:

#### Parameters:

- `names` Object
- `handler` Object
- `context` Object

## Properties

### `count`

nx.data.Collection

Inherited from nx.ui.AbstractComponent:

### `model`

Any

Inherited from nx.ui.AbstractComponent:

### `owner`

nx.ui.AbstractComponent

Inherited from nx.ui.AbstractComponent:

### `parent`

nx.ui.AbstractComponent

Inherited from nx.ui.AbstractComponent: